export class IpSLider {
    constructor() {
        this.value = 0;
        this.min = 0;
        this.max = 100;
        this.step = 1;
        this.disabled = false;
    }
    componentDidLoad() {
        this.range = this.el.shadowRoot.querySelector('input');
        this.setAttributes();
    }
    componentDidUpdate() {
        this.setAttributes();
    }
    setAttributes() {
        this.el.setAttribute('aria-disabled', `${this.disabled}`);
        this.el.setAttribute('aria-valuemax', `${this.max}`);
        this.el.setAttribute('aria-valuemin', `${this.min}`);
        this.el.setAttribute('aria-valuenow', `${+this.value}`);
        this.el.setAttribute('value', `${+this.value}`);
    }
    onInput(srcEvent) {
        srcEvent.stopPropagation();
        const { value, min, max, step } = this.range;
        this.value = +value;
        this.input.emit({
            srcEvent,
            value: +value,
            min: +min,
            max: +max,
            step: +step
        });
    }
    render() {
        return (h("input", { type: "range", onInput: ev => this.onInput(ev), disabled: this.disabled, min: this.min, max: this.max, step: this.step, value: this.value }));
    }
    static get is() { return "ip-slider"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return {
        "disabled": {
            "type": Boolean,
            "attr": "disabled",
            "reflectToAttr": true
        },
        "el": {
            "elementRef": true
        },
        "max": {
            "type": Number,
            "attr": "max"
        },
        "min": {
            "type": Number,
            "attr": "min"
        },
        "step": {
            "type": Number,
            "attr": "step"
        },
        "value": {
            "type": Number,
            "attr": "value",
            "mutable": true
        }
    }; }
    static get events() { return [{
            "name": "input",
            "method": "input",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:ip-slider:**/"; }
}
